@@ -21,12 +21,11 @@
 
 #include <boost/lexical_cast.hpp>
 
-#include <libxml++/parsers/textreader.h>
-
 #include <gtk/gtk.h>
 #include <gtkmm/image.h>
 #include <gtkmm/rc.h>
 
+#include "sharp/xmlreader.hpp"
 #include "sharp/xmlwriter.hpp"
 #include "debug.hpp"
 #include "notetag.hpp"
@@ -149,7 +148,7 @@ namespace gnote {
     }
   }
 
-  void NoteTag::read(xmlpp::TextReader & xml, bool start)
+  void NoteTag::read(sharp::XmlReader & xml, bool start)
   {
     if (can_serialize()) {
       if (start) {
@@ -308,7 +307,7 @@ namespace gnote {
     }
   }
 
-  void DynamicNoteTag::read(xmlpp::TextReader & xml, bool start)
+  void DynamicNoteTag::read(sharp::XmlReader & xml, bool start)
   {
     if (can_serialize()) {
       NoteTag::read (xml, start);
@@ -361,7 +360,7 @@ namespace gnote {
   }
 
 
-  NoteTagTable *NoteTagTable::s_instance = NULL;
+  NoteTagTable::Ptr NoteTagTable::s_instance;
 
   void NoteTagTable::_init_common_tags()
   {
@@ -545,9 +544,9 @@ namespace gnote {
   }
 
  
-  void NoteTagTable::register_dynamic_tag(const std::string & tag_name, const FactorySlot & factory)
+  void NoteTagTable::register_dynamic_tag(const std::string & tag_name, const Factory & factory)
   {
-    m_tag_types[tag_name].connect(factory);
+    m_tag_types[tag_name] = factory;
   }
 
 
